package flag;

import edu.princeton.cs.StdDraw;
import java.awt.Color;

public class Flag {

    /**
     * Draw a star.
     *
     * @param cx is the x coordinate of the star's center.
     * @param cy is the y coordinate of the star's center.
     * @param radius is the radius of the smallest circle that can contain the
     * star.
     * @param n is the number of points on the star.
     */
    public static void star(double cx, double cy, double radius, int n) {

        double[] xCoordinates = new double[2 * n];
        double[] yCoordinates = new double[2 * n];

        for (int i = 0; i < 2 * n; i++) {
            // Each vertex is a certain fraction of the 
            // distance around a circle.
            double fraction = ((double) i) / (2 * n);
            double angle = fraction * 2.0 * Math.PI;
            angle += Math.PI / (2 * n);

            // Successive vertices are alternately closer and 
            // farther from the star's center.
            double r = radius;
            if (i % 2 == 1) {
                // 0.4 is the ratio between the distance from
                // the center of the closer and farther vertices.
                r *= 0.4;
            } // if

            // Compute coordinates of a vertex.
            double x = cx + r * Math.cos(angle);
            double y = cy + r * Math.sin(angle);

            xCoordinates[i] = x;
            yCoordinates[i] = y;
        } // for

        StdDraw.filledPolygon(xCoordinates, yCoordinates);
    } // star()

    /**
     * Draw 5-pointed stars that are evenly spaced within a rectangular region.
     *
     * @param dimension is the number of rows and columns of stars.
     * @param color is the color of each star.
     * @param ulx is the x coordinate of the upper left corner of the
     * rectangular region that contains the stars.
     * @param uly is the y coordinate of the upper left corner of the
     * rectangular region that contains the stars.
     * @param width specifies the horizontal dimension of the rectangular region
     * that contains the stars.
     * @param height specifies the vertical dimension of the rectangular region
     * that contains the stars.
     */
    public static void starField(int dimension, Color color,
            double ulx, double uly, double width, double height) {
        StdDraw.setPenColor(color);
        double size = 1.0 / (2 * dimension);

        for (int i = 0; i < dimension; i++) {
            // starting from the bottom of the space that
            // we have allowed for drawing stars, what fraction
            // of the vertical space must we move to find the
            // position for the stars in this row?
            double yFraction = ((double) i) / dimension;
            double y = uly - yFraction * height;
            for (int j = 0; j < dimension; j++) {
                // starting from the left edge of the space that
                // we have allowed for drawing stars, what fraction
                // of the horizontal space must we move to find the
                // position for this next star?
                double xFraction = ((double) j) / dimension;
                double x = ulx + xFraction * width;

                star(x, y, size, 5);
            } // for
        } // for
    } // starField()

    /**
     * Draw one stripe (a rectangle).
     *
     * @param ulx is the x coordinate of the upper left corner.
     * @param uly is the y coordinate of the upper left corner.
     * @param width is the width of the rectangle.
     * @param height is the height of the rectangle.
     * @param color is the color of the rectangle.
     */
    public static void stripe(double ulx, double uly,
            double width, double height, Color color) {

        double cx = ulx + width / 2;
        double cy = uly - height / 2;
        double halfWidth = width / 2;
        double halfHeight = height / 2;
        StdDraw.setPenColor(color);
        StdDraw.filledRectangle(cx, cy, halfWidth, halfHeight);
    } // stripe( double, double, double, double, Color )

    public static void main(String[] args) {
        StdDraw.setCanvasSize(512, 512);
        StdDraw.setXscale(-1.0, +1.0);
        StdDraw.setYscale(-1.0, +1.0);

        for (int i = 0; i < 13; i++) {
            double y = ((double) i) / 13 * 2 - 1;
            if (i % 2 == 0) {
                stripe(-1.0, y, 2.0, 2.0 / 13.0, Color.RED);
            } // if
            else {
                stripe(-1.0, y, 2.0, 2.0 / 13.0, Color.WHITE);
            }
        } // for
        
        stripe( -1.0, 1.0, 1.0, 1.0, Color.BLUE );

        starField(7, Color.WHITE, -1.0, 1.0, 1.0, 1.0);
    } // main( String [] )

} // Flag
